# -*- coding: utf-8 -*-

from purifier.purifier import HTMLPurifier
from purifier.whitelist import WHITELIST

from thorium.fields import CharField
from thorium.validators import CharValidator


class HTMLValidator(CharValidator):

    purifier = HTMLPurifier(WHITELIST, validate=True)

    def additional_validation(self, value):
        super().additional_validation(value)
        self.purifier.feed(value)


class HTMLField(CharField):
    validator_type = HTMLValidator



# -*- coding: utf-8 -*-

import unittest

from unittest.mock import MagicMock

from purifier.purifier import InvalidTagException, InvalidAttributeException

from thorium_htmlpurifier import HTMLValidator


class TestHTMLPurifierValidator(unittest.TestCase):
    def test_bad_tag(self):
        field = MagicMock()
        field.flags.__getitem__.return_value = 0
        value = "<script></script>"
        validator = HTMLValidator(field)
        self.assertRaises(InvalidTagException,
                          lambda: validator.validate(value))

    def test_bad_attribute(self):
        field = MagicMock()
        field.flags.__getitem__.return_value = 0
        value = "<div onclick='alert();'></div>"
        validator = HTMLValidator(field)
        self.assertRaises(InvalidAttributeException,
                          lambda: validator.validate(value))

    def test_valid_markup(self):
        field = MagicMock()
        field.flags.__getitem__.return_value = 0
        value = "<div></div><p></p><a></a><hr><br>"
        validator = HTMLValidator(field)
        self.assertTrue(validator.validate(value))



# -*- coding: utf-8 -*-

from setuptools import setup


setup(
    name='thorium_htmlpurifier',
    description='HTML Purifier validation for Thorium',
    packages=['thorium_htmlpurifier'],
    version='0.1.0',
    author='Devon Meunier',
    author_email='devon@eventmobi.com',
    url='https://github.com/meunierd/thorium_htmlpurifier/',
    install_requires=[
        'thorium',
        'html-purifier3>=2.1.0',
    ],
    test_suite='nose.collector',
)
